@@ -14,76 +14,41 @@
 # limitations under the License.
 #
 
-from google.cloud.orchestration.airflow.service_v1.services.environments.client import (
-    EnvironmentsClient,
-)
 from google.cloud.orchestration.airflow.service_v1.services.environments.async_client import (
     EnvironmentsAsyncClient,
 )
-from google.cloud.orchestration.airflow.service_v1.services.image_versions.client import (
-    ImageVersionsClient,
+from google.cloud.orchestration.airflow.service_v1.services.environments.client import (
+    EnvironmentsClient,
 )
 from google.cloud.orchestration.airflow.service_v1.services.image_versions.async_client import (
     ImageVersionsAsyncClient,
 )
-
+from google.cloud.orchestration.airflow.service_v1.services.image_versions.client import (
+    ImageVersionsClient,
+)
 from google.cloud.orchestration.airflow.service_v1.types.environments import (
     CheckUpgradeResponse,
-)
-from google.cloud.orchestration.airflow.service_v1.types.environments import (
     CreateEnvironmentRequest,
-)
-from google.cloud.orchestration.airflow.service_v1.types.environments import (
     DatabaseConfig,
-)
-from google.cloud.orchestration.airflow.service_v1.types.environments import (
     DeleteEnvironmentRequest,
-)
-from google.cloud.orchestration.airflow.service_v1.types.environments import (
     EncryptionConfig,
-)
-from google.cloud.orchestration.airflow.service_v1.types.environments import Environment
-from google.cloud.orchestration.airflow.service_v1.types.environments import (
+    Environment,
     EnvironmentConfig,
-)
-from google.cloud.orchestration.airflow.service_v1.types.environments import (
     GetEnvironmentRequest,
-)
-from google.cloud.orchestration.airflow.service_v1.types.environments import (
     IPAllocationPolicy,
-)
-from google.cloud.orchestration.airflow.service_v1.types.environments import (
     ListEnvironmentsRequest,
-)
-from google.cloud.orchestration.airflow.service_v1.types.environments import (
     ListEnvironmentsResponse,
-)
-from google.cloud.orchestration.airflow.service_v1.types.environments import NodeConfig
-from google.cloud.orchestration.airflow.service_v1.types.environments import (
+    NodeConfig,
     PrivateClusterConfig,
-)
-from google.cloud.orchestration.airflow.service_v1.types.environments import (
     PrivateEnvironmentConfig,
-)
-from google.cloud.orchestration.airflow.service_v1.types.environments import (
     SoftwareConfig,
-)
-from google.cloud.orchestration.airflow.service_v1.types.environments import (
     UpdateEnvironmentRequest,
-)
-from google.cloud.orchestration.airflow.service_v1.types.environments import (
     WebServerConfig,
-)
-from google.cloud.orchestration.airflow.service_v1.types.environments import (
     WebServerNetworkAccessControl,
 )
 from google.cloud.orchestration.airflow.service_v1.types.image_versions import (
     ImageVersion,
-)
-from google.cloud.orchestration.airflow.service_v1.types.image_versions import (
     ListImageVersionsRequest,
-)
-from google.cloud.orchestration.airflow.service_v1.types.image_versions import (
     ListImageVersionsResponse,
 )
 from google.cloud.orchestration.airflow.service_v1.types.operations import (
